@@ -8,12 +8,13 @@ import Distribution.Simple ( defaultMainWithHooks, UserHooks(postConf),
 import Gtk2HsSetup ( gtk2hsUserHooks, getPkgConfigPackages)
 import Distribution.Simple.Setup ( ConfigFlags(configVerbosity), fromFlag)
 import Distribution.Simple.LocalBuildInfo ( LocalBuildInfo(..) )
-import Distribution.Simple.BuildPaths ( autogenModulesDir )
+import Distribution.Simple.BuildPaths ( autogenPackageModulesDir )
 import Distribution.Text ( display )
 import Distribution.Version ( Version(..) )
 import Distribution.Verbosity
-import Distribution.Simple.Utils
+import Distribution.Simple.Utils hiding (die)
 import System.FilePath
+import System.Exit (die)
 
 #if MIN_VERSION_Cabal(2,0,0)
 import Distribution.Version ( versionNumbers )
@@ -42,13 +43,13 @@ writePangoVersionHeaderFile verbosity lbi (versionNumbers -> (major:minor:micro:
 writePangoVersionHeaderFile verbosity lbi (Version (major:minor:micro:_) []) = do
 #endif
   createDirectoryIfMissingVerbose verbosity True targetDir
-  rewriteFile targetFile $ unlines
+  rewriteFileEx verbosity targetFile $ unlines
     [ "#define PANGO_VERSION_MAJOR " ++ show major
     , "#define PANGO_VERSION_MINOR " ++ show minor
     , "#define PANGO_VERSION_MICRO " ++ show micro
     ]
   where
-    targetDir  = autogenModulesDir lbi
+    targetDir  = autogenPackageModulesDir lbi
     targetFile = targetDir </> "hspangoversion.h"
 
 writeVersionHeaderFile _ _ version =
